# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import ContentTypes, EntityState, FileTypes


class UpdateContent(BaseModel):
    update_content: Optional["UpdateContentUpdateContent"] = Field(
        alias="updateContent"
    )


class UpdateContentUpdateContent(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    uri: Optional[Any]
    collections: Optional[List[Optional["UpdateContentUpdateContentCollections"]]]


class UpdateContentUpdateContentCollections(BaseModel):
    id: str
    name: str


UpdateContent.model_rebuild()
UpdateContentUpdateContent.model_rebuild()
