# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import CollectionTypes, EntityState


class AddContentsToCollections(BaseModel):
    add_contents_to_collections: Optional[
        List[Optional["AddContentsToCollectionsAddContentsToCollections"]]
    ] = Field(alias="addContentsToCollections")


class AddContentsToCollectionsAddContentsToCollections(BaseModel):
    id: str
    name: str
    state: EntityState
    type: Optional[CollectionTypes]
    contents: Optional[
        List[Optional["AddContentsToCollectionsAddContentsToCollectionsContents"]]
    ]


class AddContentsToCollectionsAddContentsToCollectionsContents(BaseModel):
    id: str
    name: str


AddContentsToCollections.model_rebuild()
AddContentsToCollectionsAddContentsToCollections.model_rebuild()
