# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalStudy(BaseModel):
    delete_medical_study: Optional["DeleteMedicalStudyDeleteMedicalStudy"] = Field(
        alias="deleteMedicalStudy"
    )


class DeleteMedicalStudyDeleteMedicalStudy(BaseModel):
    id: str
    state: EntityState


DeleteMedicalStudy.model_rebuild()
