# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountSpecifications(BaseModel):
    count_specifications: Optional["CountSpecificationsCountSpecifications"] = Field(
        alias="countSpecifications"
    )


class CountSpecificationsCountSpecifications(BaseModel):
    count: Optional[Any]


CountSpecifications.model_rebuild()
