# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalTherapy(BaseModel):
    create_medical_therapy: Optional["CreateMedicalTherapyCreateMedicalTherapy"] = (
        Field(alias="createMedicalTherapy")
    )


class CreateMedicalTherapyCreateMedicalTherapy(BaseModel):
    id: str
    name: str


CreateMedicalTherapy.model_rebuild()
