# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, FeedTypes


class CreateFeed(BaseModel):
    create_feed: Optional["CreateFeedCreateFeed"] = Field(alias="createFeed")


class CreateFeedCreateFeed(BaseModel):
    id: str
    name: str
    state: EntityState
    type: FeedTypes


CreateFeed.model_rebuild()
