# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateLabel(BaseModel):
    create_label: Optional["CreateLabelCreateLabel"] = Field(alias="createLabel")


class CreateLabelCreateLabel(BaseModel):
    id: str
    name: str


CreateLabel.model_rebuild()
