# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalTest(BaseModel):
    update_medical_test: Optional["UpdateMedicalTestUpdateMedicalTest"] = Field(
        alias="updateMedicalTest"
    )


class UpdateMedicalTestUpdateMedicalTest(BaseModel):
    id: str
    name: str


UpdateMedicalTest.model_rebuild()
